import React, { useState, useCallback, useRef } from 'react';
import { Link } from 'wouter';
import { SiX, SiBluesky } from 'react-icons/si';
import {
  NavigationMenu,
  NavigationMenuList,
  NavigationMenuItem,
  NavigationMenuTrigger,
  NavigationMenuContent,
} from "@/components/ui/navigation-menu";
import { Lightbulb, Menu, X, Moon, Sun } from 'lucide-react';
import { Button } from "@/components/ui/button";
import Logo from './logo';
import {
  Tooltip,
  TooltipContent,
  TooltipProvider,
  TooltipTrigger,
} from "@/components/ui/tooltip";

// Declare gtag global for TypeScript
declare global {
  interface Window {
    gtag?: (command: string, action: string, params: object) => void;
  }
}
import {
  Sheet,
  SheetContent,
  SheetTrigger,
  SheetTitle,
  SheetDescription,
  SheetHeader,
  SheetClose,
} from "@/components/ui/sheet";

export default function Header() {
  // Create a ref for the SheetClose button
  const sheetCloseRef = useRef<HTMLButtonElement>(null);

  // Function to close the mobile menu sheet
  const closeSheet = () => {
    sheetCloseRef.current?.click();
  };

  // Shared theme toggle function
  const toggleTheme = useCallback(() => {
    const html = document.documentElement;
    const currentTheme = html.classList.contains('dark') ? 'dark' : 'light';
    const newTheme = currentTheme === 'light' ? 'dark' : 'light';

    html.classList.remove('light', 'dark');
    html.classList.add(newTheme);
    localStorage.setItem('theme', newTheme);
  }, []);

  return (
    <header className="sticky top-0 z-50 w-full bg-background/95 backdrop-blur-sm border-b border-border/40">
      <div className="container px-2 md:px-8 flex h-16 items-center justify-between">
        {/* Site Name and Navigation */}
        <div className="flex items-center gap-2 pl-2 sm:pl-4">
          <Link 
            href="/" 
            className="flex items-center min-h-[32px] min-w-[32px]"
            aria-label="Return to Into Solana homepage - Explore Solana blockchain projects"
            title="Into Solana - Homepage for Solana ecosystem projects directory"
          >
            <span className="font-bold text-[22px] sm:text-[24px] md:text-2xl tracking-tight text-foreground leading-none">Into Solana</span>
          </Link>

          {/* Vertical separator - hide on small screens */}
          <div className="hidden sm:block h-6 w-px bg-border mx-2"></div>

          {/* Desktop Navigation */}
          <nav className="hidden md:flex items-center gap-4 lg:gap-6">
            <Link 
              href="/about" 
              className="text-muted-foreground hover:text-foreground transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 rounded-sm px-2 py-1"
              aria-label="About Into Solana - Our mission and team"
              title="Learn about Into Solana's mission and the team behind the platform"
            >
              About
            </Link>
            <Link 
              href="/blog" 
              className="text-muted-foreground hover:text-foreground transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 rounded-sm px-2 py-1"
              aria-label="Into Solana Blog - Latest Solana ecosystem news and insights"
              title="Read the latest news, guides, and insights about the Solana blockchain ecosystem"
            >
              Blog
            </Link>
            <NavigationMenu>
              <NavigationMenuList>
                <NavigationMenuItem>
                  <NavigationMenuTrigger>Learn</NavigationMenuTrigger>
                  <NavigationMenuContent>
                    <div className="w-[200px] p-3">
                      <Link 
                        href="/learn-solana" 
                        className="block p-2 hover:bg-accent rounded-md"
                        title="Learn about Solana blockchain technology and development"
                        aria-label="Learn Solana - Beginner friendly guides and tutorials"
                      >
                        Learn Solana
                      </Link>
                      <Link 
                        href="/lets-build" 
                        className="block p-2 hover:bg-accent rounded-md"
                        title="Step-by-step guides for building Solana projects"
                        aria-label="Build Projects on Solana - Development tutorials and examples"
                      >
                        Build Projects
                      </Link>
                      <Link 
                        href="/jobs" 
                        className="block p-2 hover:bg-accent rounded-md"
                        title="Find Solana ecosystem job opportunities"
                        aria-label="Solana Jobs - Career opportunities in the Solana ecosystem"
                      >
                        Jobs
                      </Link>
                    </div>
                  </NavigationMenuContent>
                </NavigationMenuItem>
              </NavigationMenuList>
            </NavigationMenu>
            <Link 
              href="/submit" 
              className="text-muted-foreground hover:text-foreground transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 rounded-sm px-2 py-1"
              aria-label="Submit a Solana project to our directory"
              title="Add your Solana project or application to the Into Solana directory"
            >
              Submit
            </Link>
          </nav>
        </div>

        <div className="flex items-center">
          {/* Theme Toggle for Desktop */}
          <div className="hidden sm:flex mr-4">
            <Button
              variant="ghost"
              size="icon"
              onClick={toggleTheme}
              className="w-9 h-9"
              aria-label="Toggle theme"
            >
              <Sun className="h-5 w-5 rotate-0 scale-100 transition-all dark:-rotate-90 dark:scale-0" />
              <Moon className="absolute h-5 w-5 rotate-90 scale-0 transition-all dark:rotate-0 dark:scale-100" />
              <span className="sr-only">Toggle theme</span>
            </Button>
          </div>

          {/* Social Media Icons - Hide on very small screens */}
          <div className="hidden sm:flex items-center gap-3 md:gap-6 pr-4" itemScope itemType="https://schema.org/Organization">
            <meta itemProp="name" content="Into Solana" />
            <link itemProp="url" href="https://intosolana.com" />

            <TooltipProvider>
              <Tooltip>
                <TooltipTrigger asChild>
                  <a
                    href="https://www.bulbapp.io/u/5J8mT2SH2BXmd6tvSasvsDkvSvUtQBxHfeK6bn3hqhoC/into-solana"
                    target="_blank"
                    rel="noopener noreferrer me"
                    className="text-primary hover:text-primary/80 transition-colors social-link bulb-social-link"
                    aria-label="Into Solana on BULB - Solana Social Network at BULBapp.io"
                    title="Follow Into Solana on BULB (BULBapp.io) - The Web3 Social Network for Solana"
                    itemProp="sameAs"
                    data-social-platform="bulb"
                    data-bulbapp-profile="true"
                  >
                    <Lightbulb className="w-5 h-5" />
                    <span className="sr-only">IntoSolana.com on BULB (BULBapp.io) - Official Solana Social Network</span>
                    <meta itemProp="name" content="BULB Social Profile for IntoSolana.com - BULBapp.io" />
                    <meta itemProp="description" content="Follow IntoSolana.com on BULB (BULBapp.io), the leading Web3 social network for Solana enthusiasts." />
                  </a>
                </TooltipTrigger>
                <TooltipContent>
                  <p>Follow Us on <strong>BULB</strong> (BULBapp.io)</p>
                </TooltipContent>
              </Tooltip>
            </TooltipProvider>

            <TooltipProvider>
              <Tooltip>
                <TooltipTrigger asChild>
                  <a
                    href="https://x.com/_Intosolana"
                    target="_blank"
                    rel="noopener noreferrer me"
                    className="text-primary hover:text-primary/80 transition-colors social-link"
                    aria-label="Into Solana on Twitter/X - Solana Projects and Updates"
                    title="Follow Into Solana on Twitter/X for Latest Solana Ecosystem Updates"
                    itemProp="sameAs"
                    data-social-platform="twitter"
                  >
                    <SiX className="w-5 h-5" />
                    <span className="sr-only">Into Solana on Twitter/X</span>
                  </a>
                </TooltipTrigger>
                <TooltipContent>
                  <p>Follow Us on X</p>
                </TooltipContent>
              </Tooltip>
            </TooltipProvider>

            <TooltipProvider>
              <Tooltip>
                <TooltipTrigger asChild>
                  <a
                    href="https://bsky.app/profile/intosolana.bsky.social"
                    target="_blank"
                    rel="noopener noreferrer me"
                    className="text-primary hover:text-primary/80 transition-colors social-link"
                    aria-label="Into Solana on BlueSky - Solana Ecosystem News"
                    title="Join Into Solana on BlueSky for Solana Ecosystem Insights"
                    itemProp="sameAs"
                    data-social-platform="bluesky"
                  >
                    <SiBluesky className="w-5 h-5" />
                    <span className="sr-only">Into Solana on BlueSky</span>
                  </a>
                </TooltipTrigger>
                <TooltipContent>
                  <p>Follow Us on Bluesky</p>
                </TooltipContent>
              </Tooltip>
            </TooltipProvider>
          </div>

          {/* Mobile Menu */}
          <Sheet>
            <SheetTrigger asChild className="md:hidden">
              <button
                className="flex h-8 w-8 items-center justify-center rounded-md border border-primary/40 bg-background hover:bg-primary/5 hover:text-primary hover:border-primary/60 mr-1.5 transition-all shadow-sm hover:shadow-primary/20"
                aria-label="Open navigation menu"
              >
                <Menu className="h-4 w-4 text-primary/80" />
                <span className="sr-only">Toggle mobile menu</span>
              </button>
            </SheetTrigger>
            <SheetContent side="right" className="w-[240px] sm:w-[260px]">
              {/* Hidden close button that we'll trigger via ref */}
              <SheetClose ref={sheetCloseRef} className="sr-only">
                Close
              </SheetClose>

              <div className="flex justify-end items-center py-4 mb-6 border-b border-border">
                <div className="pr-4">
                  <Button
                    variant="outline"
                    size="icon"
                    onClick={toggleTheme}
                    className="w-9 h-9"
                  >
                    <Sun className="h-5 w-5 rotate-0 scale-100 transition-all dark:-rotate-90 dark:scale-0" />
                    <Moon className="absolute h-5 w-5 rotate-90 scale-0 transition-all dark:rotate-0 dark:scale-100" />
                  </Button>
                </div>
              </div>

              <div className="flex flex-col h-full">
                <div className="space-y-8">
                  {/* Main Navigation Section */}
                  <nav className="flex flex-col space-y-1">
                    <Link 
                      href="/" 
                      onClick={closeSheet} 
                      className="flex items-center py-3 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring" 
                      aria-current={window?.location?.pathname === "/" ? "page" : undefined}
                      aria-label="Return to Into Solana homepage - Explore Solana blockchain projects"
                      title="Into Solana - Homepage for Solana ecosystem projects directory"
                    >
                      <span className="text-base font-medium">Home</span>
                    </Link>
                    <Link 
                      href="/jobs" 
                      onClick={closeSheet} 
                      className="flex items-center py-3 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring" 
                      aria-current={window?.location?.pathname === "/jobs" ? "page" : undefined}
                      aria-label="Solana Jobs - Career opportunities in the Solana ecosystem" 
                      title="Find Solana ecosystem job opportunities"
                    >
                      <span className="text-base font-medium">Jobs</span>
                    </Link>
                    <Link 
                      href="/about" 
                      onClick={closeSheet} 
                      className="flex items-center py-3 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring" 
                      aria-current={window?.location?.pathname === "/about" ? "page" : undefined}
                      aria-label="About Into Solana - Our mission and team"
                      title="Learn about Into Solana's mission and the team behind the platform"
                    >
                      <span className="text-base font-medium">About</span>
                    </Link>
                    <Link 
                      href="/blog" 
                      onClick={closeSheet} 
                      className="flex items-center py-3 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring" 
                      aria-current={window?.location?.pathname === "/blog" ? "page" : undefined}
                      aria-label="Into Solana Blog - Latest Solana ecosystem news and insights"
                      title="Read the latest news, guides, and insights about the Solana blockchain ecosystem"
                    >
                      <span className="text-base font-medium">Blog</span>
                    </Link>
                    <Link 
                      href="/learn-solana" 
                      onClick={closeSheet} 
                      className="flex items-center py-3 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring" 
                      aria-current={window?.location?.pathname === "/learn-solana" ? "page" : undefined}
                      aria-label="Learn Solana - Beginner friendly guides and tutorials"
                      title="Learn about Solana blockchain technology and development"
                    >
                      <span className="text-base font-medium">Learn Solana</span>
                    </Link>
                    <Link 
                      href="/lets-build" 
                      onClick={closeSheet} 
                      className="flex items-center py-3 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring" 
                      aria-current={window?.location?.pathname === "/lets-build" ? "page" : undefined}
                      aria-label="Build Projects on Solana - Development tutorials and examples"
                      title="Step-by-step guides for building Solana projects"
                    >
                      <span className="text-base font-medium">Build</span>
                    </Link>
                    <Link 
                      href="/submit" 
                      onClick={closeSheet} 
                      className="flex items-center py-3 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring" 
                      aria-current={window?.location?.pathname === "/submit" ? "page" : undefined}
                      aria-label="Submit a Solana project to our directory"
                      title="Add your Solana project or application to the Into Solana directory"
                    >
                      <span className="text-base font-medium">Submit Project</span>
                    </Link>
                  </nav>

                  {/* Social Links Section */}
                  <div className="pt-8 border-t border-border">
                    <h3 className="text-sm font-semibold mb-4 text-right pr-4">
                      Connect with Us
                    </h3>
                    <div className="flex flex-col space-y-3">
                      <a
                        href="https://www.bulbapp.io/u/5J8mT2SH2BXmd6tvSasvsDkvSvUtQBxHfeK6bn3hqhoC/into-solana"
                        target="_blank"
                        rel="noopener noreferrer me"
                        className="flex items-center gap-3 py-2 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end bulb-mobile-link focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring"
                        aria-label="Into Solana on BULB (BULBapp.io) - Official Solana Social Network"
                        title="Follow IntoSolana on BULB at BULBapp.io - Web3 Social Network"
                        data-bulbapp-mobile="true"
                        onClick={() => {
                          // Add tracking for BULB clicks
                          if (typeof window !== 'undefined' && window.gtag) {
                            window.gtag('event', 'click', {
                              event_category: 'social_links',
                              event_label: 'BULB_mobile_menu',
                              value: 1
                            });
                          }
                        }}
                      >
                        <Lightbulb className="w-5 h-5 flex-shrink-0" aria-hidden="true" />
                        <span className="font-medium">BULB</span>
                        <span className="sr-only">(BULBapp.io)</span>
                      </a>
                      <a
                        href="https://x.com/_Intosolana"
                        target="_blank"
                        rel="noopener noreferrer me"
                        className="flex items-center gap-3 py-2 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring"
                        aria-label="Into Solana on X/Twitter - Solana Projects and Updates"
                        title="Follow Into Solana on Twitter/X for Latest Solana Ecosystem Updates"
                      >
                        <SiX className="w-5 h-5 flex-shrink-0" aria-hidden="true" />
                        <span className="font-medium">Twitter</span>
                      </a>
                      <a
                        href="https://bsky.app/profile/intosolana.bsky.social"
                        target="_blank"
                        rel="noopener noreferrer me"
                        className="flex items-center gap-3 py-2 px-4 rounded-md text-primary hover:bg-primary hover:text-white transition-colors justify-end focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring"
                        aria-label="Into Solana on BlueSky - Solana Ecosystem News"
                        title="Join Into Solana on BlueSky for Solana Ecosystem Insights"
                      >
                        <SiBluesky className="w-5 h-5 flex-shrink-0" aria-hidden="true" />
                        <span className="font-medium">Bluesky</span>
                      </a>
                    </div>
                  </div>

                  {/* Privacy Policy Link */}
                  <div className="pt-8 mt-auto border-t border-border">
                    <Link 
                      href="/privacy-policy" 
                      onClick={closeSheet}
                      className="flex items-center gap-3 py-2 px-4 rounded-md text-muted-foreground hover:text-primary transition-colors justify-end text-sm"
                      aria-label="View Into Solana's Privacy Policy"
                      title="Learn how we handle your data and privacy concerns"
                    >
                      <span>Privacy Policy</span>
                    </Link>
                  </div>
                </div>
              </div>
            </SheetContent>
          </Sheet>
        </div>
      </div>
    </header>
  );
}